@@ -21,7 +21,7 @@ class LimitRange(NamespacedResource):
         super().__init__(**kwargs)
         self.limits = limits
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             if not self.limits:
